@@ -17,8 +17,7 @@ sub EXT_controller : Extend('Ext.app.ViewController') : Type('controller') {
         },
 
         # MATERIAL THEME
-        currentTheme => undef,
-        defautTheme  => {
+        defautTheme => {
             accent   => 'grey',
             base     => 'blue-grey',
             darkMode => \0
@@ -61,7 +60,7 @@ sub EXT_controller : Extend('Ext.app.ViewController') : Type('controller') {
             }
 
             // set material theme
-            me.setTheme();
+            me._applyTheme(me._getCurrentTheme());
 
             this.getViewModel().bind('{session.theme.darkMode}', function (newVal, oldVal, eOpt) {
                 if (newVal == null) return;
@@ -155,7 +154,7 @@ JS
             session.locale = locale;
             session.localeName = session.locales[locale];
 
-            session.theme = this.currentTheme;
+            session.theme = this._getCurrentTheme();
 
             // update viewModel
             var viewModel = this.getViewModel();
@@ -166,25 +165,30 @@ JS
 
         # MATERIAL THEME
         setTheme => func ['theme'], <<"JS",
-            if (Ext.theme.Material) {
-                Ext.manifest.material = Ext.manifest.material || {};
-                Ext.manifest.material.toolbar = Ext.manifest.material.toolbar || {};
-                Ext.manifest.material.toolbar.dynamic = true;
+            if (!Ext.theme.Material) return;
 
-                var userTheme = this.currentTheme;
-                if (!userTheme) userTheme = localStorage.theme ? JSON.parse(localStorage.theme) : {};
+            theme = Ext.apply(this._getCurrentTheme(), theme);
 
-                if (!theme) {
-                    this.currentTheme = Ext.apply({}, userTheme, this.defaultTheme);
-                }
-                else {
-                    this.currentTheme = Ext.apply({}, theme, userTheme);
+            localStorage.theme = JSON.stringify(theme);
 
-                    localStorage.theme = JSON.stringify(this.currentTheme);
-                }
+            var session = this.getViewModel().get('session');
+            if (session) session.theme = theme;
 
-                Ext.theme.Material.setColors(this.currentTheme);
-            }
+            this._applyTheme(theme);
+JS
+
+        _getCurrentTheme => func <<'JS',
+            return Ext.apply({}, localStorage.theme ? JSON.parse(localStorage.theme) : {}, this.defaultTheme);
+JS
+
+        _applyTheme => func ['theme'], <<'JS',
+            if (!Ext.theme.Material) return;
+
+            Ext.manifest.material = Ext.manifest.material || {};
+            Ext.manifest.material.toolbar = Ext.manifest.material.toolbar || {};
+            Ext.manifest.material.toolbar.dynamic = true;
+
+            Ext.theme.Material.setColors(theme);
 JS
 
         # MASK
